# lanku

## LANK User

User interface which utilizes the LANK protocol.

## Installation

It is easy to install lanku using pip:
```
pip install lanku
```

## Usage

Once installed, simply run the `lanku` command from any terminal.

